<?php

namespace Drupal\codit_batch_operations\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Url;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining BatchOpLog entities.
 *
 * @ingroup batch_op_log
 */
interface BatchOpLogInterface extends ContentEntityInterface, EntityOwnerInterface {

  /**
   * Gets the BatchOpLog name.
   *
   * @return string
   *   Name of the BatchOpLog entity.
   */
  public function getName(): string;

  /**
   * Sets the BatchOpLog name.
   *
   * @param string $name
   *   The BatchOpLog name.
   *
   * @return \Drupal\codit_batch_operations\Entity\BatchOpLogInterface
   *   The called BatchOpLog entity.
   */
  public function setName(string $name): BatchOpLogInterface;

  /**
   * Sets the executor property.
   *
   * @param string $executor
   *   The id of the executor.
   *
   * @return \Drupal\codit_batch_operations\Entity\BatchOpLogInterface
   *   The called BatchOpLog entity.
   */
  public function setExecutor(string $executor): BatchOpLogInterface;

  /**
   * Appends a message to the current BatchOpLog log.
   *
   * @param string $message
   *   The message to append.
   *
   * @return \Drupal\codit_batch_operations\Entity\BatchOpLogInterface
   *   The BatchOpLog.
   */
  public function appendLog(string $message): BatchOpLogInterface;

  /**
   * Appends an error to the current BatchOpLog errors.
   *
   * @param string $message
   *   The message to append.
   *
   * @return \Drupal\codit_batch_operations\Entity\BatchOpLogInterface
   *   The BatchOpLog.
   */
  public function appendError($message): BatchOpLogInterface;

  /**
   * Getter for errors.
   *
   * @return ?string
   *   The errors logged.
   */
  public function getErrors(): ?string;

  /**
   * Gets the BatchOpLog creation timestamp.
   *
   * @return int
   *   Creation timestamp of the BatchOpLog.
   */
  public function getCreatedTime();

  /**
   * Sets the BatchOpLog creation timestamp.
   *
   * @param int $timestamp
   *   The BatchOpLog creation timestamp.
   *
   * @return \Drupal\codit_batch_operations\Entity\BatchOpLogInterface
   *   The called BatchOpLog entity.
   */
  public function setCreatedTime(int $timestamp): BatchOpLogInterface;

  /**
   * Reads the BatchOpLog field and returns the requested parameter.
   *
   * @param string $element
   *   The name of the element to get (type, bundle, or field).
   *
   * @return string
   *   The name of the script being logged.
   */
  public function getBatchOpLogScriptName($element): string;

  /**
   * Gets the drupal URL for the BatchOpLog.
   *
   * @return string
   *   URL for the current BatchOpLog.
   */
  public function getUrl(): Url;

}
